==> haskell-hashable-1.2.4.0-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hashable
version: 1.2.4.0
id: hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
key: hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
license: BSD3
maintainer: johan.tibell@gmail.com
stability: Provisional
homepage: http://github.com/tibbe/hashable
synopsis: A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.
category: Data
author: Milan Straka <fox@ucw.cz>
        Johan Tibell <johan.tibell@gmail.com>
exposed: True
exposed-modules:
    Data.Hashable
hidden-modules: Data.Hashable.Class Data.Hashable.Generic
abi: 3530cf0f156cd0fb90097c338b4b1201
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hashable-1.2.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hashable-1.2.4.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/hashable-1.2.4.0
hs-libraries: HShashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
depends:
    base-4.9.0.0 bytestring-0.10.8.1 ghc-prim-0.5.0.0
    integer-gmp-1.0.0.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html: /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-1.2.5.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hashable
version: 1.2.5.0
id: hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
key: hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
license: BSD3
maintainer: johan.tibell@gmail.com
stability: Provisional
homepage: http://github.com/tibbe/hashable
synopsis: A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.
category: Data
author: Milan Straka <fox@ucw.cz>
        Johan Tibell <johan.tibell@gmail.com>
exposed: True
exposed-modules:
    Data.Hashable Data.Hashable.Lifted
hidden-modules: Data.Hashable.Class Data.Hashable.Generic
abi: 553dd4bef6c565265f0f1fb9eeec93c8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hashable-1.2.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hashable-1.2.5.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/hashable-1.2.5.0
hs-libraries: HShashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
depends:
    base-4.9.0.0 bytestring-0.10.8.1 ghc-prim-0.5.0.0
    integer-gmp-1.0.0.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html: /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
